@@ -1,6 +1,6 @@
 #-*-perl-*-
 #---------------------------------------------------------------------------
-# Copyright (C) 2004 Jrg Tiedemann  <joerg@stp.ling.uu.se>
+# Copyright (C) 2004-2012 Joerg Tiedemann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -37,9 +37,12 @@ This library provides the main methods for loading Uplug modules and running the
 
 =head1 USAGE
 
-For imformation on how to use the Uplug toolkit with the provided modules can be found here:
+More information on how to use the Uplug toolkit with the provided modules can be found here:
 L<uplug>
 
+Add-ons and language-specific modules can be downloaded from the Uplug project website at bitbucket: L<https://bitbucket.org/tiedemann/uplug>
+
+
 =cut
 
 
@@ -59,7 +62,7 @@ use vars qw($VERSION $AUTHOR $DEBUG);
 use vars qw(@TempFiles);
 
 
-$VERSION = '0.3.3';
+$VERSION = '0.3.4';
 $AUTHOR  = 'Joerg Tiedemann';
 $DEBUG = 0;
 
@@ -406,9 +409,7 @@ sub output{
 	    }
 	    $self->{DATA}->{$_}=$output->{$_};
 	}
-	if (exists $self->{MODULE}){
-	    &WriteConfig($self->{MODULE},$self->{CONFIG});
-	}
+	$self->load();
     }
     return &GetParam($self->{CONFIG},'output');
 }
